@@ -72,8 +72,8 @@
 #include <unistd.h>
 #include <string.h>
 
-#include <isdn.h>
-#include <isdnif.h>
+#include <linux/isdn.h>
+#include <linux/isdnif.h>
 
 char *l2protostr[] = {"x75i", "x75ui", "x75bui", "hdlc", "\0"};
 int  l2protoval[]  = {ISDN_PROTO_L2_X75I, ISDN_PROTO_L2_X75UI,
@@ -121,6 +121,8 @@ usage(void) {
   fprintf(stderr,"    sdelay mastername delay    (set slave-activation delay\n");
   fprintf(stderr,"    dial name                  (force dialing of interface\n");
   fprintf(stderr,"    system on|off              (switch isdn-system on or off)\n");
+  fprintf(stderr,"    addlink name               (MP, increase number of links)\n");
+  fprintf(stderr,"    removelink name            (MP, decrease number of links)\n");
   exit(-2);
 }
 
@@ -847,7 +849,45 @@ main(int argc, char **argv) {
 	     num2key(cfg.l3_proto,l3protostr,l3protoval));
       close(fd);
       return;
-    }  
+    } 
+    if(!strcmp(argv[1],"addlink")) {
+      if(argc!=3)
+        usage();
+      if(strlen(argv[2])>8) {
+        fprintf(stderr,"name must not exceed 8 characters\n");
+        exit(-1);
+      }
+      if((result=ioctl(fd,ISDN_IOCTL_NET_ADD_LINK,argv[2]))<0)
+      {
+        perror(argv[2]);
+        exit(-1);
+      }
+      if(result)
+        printf("Can't increase number of links: %d\n",result);
+      else
+        printf("Ok, added a new link. (dialing)\n");
+      close(fd);
+      return; 
+    }
+    if(!strcmp(argv[1],"removelink")) {
+      if(argc!=3)
+        usage();
+      if(strlen(argv[2])>8) {
+        fprintf(stderr,"name must not exceed 8 characters\n");
+        exit(-1);
+      }
+      if((result=ioctl(fd,ISDN_IOCTL_NET_REMOVE_LINK,argv[2]))<0)
+      {
+        perror(argv[2]);
+        exit(-1);
+      }
+      if(result)
+        printf("Can't decrease number of links: %d\n",result);
+      else
+        printf("Ok, removed a link. (hangup)\n");
+      close(fd);
+      return;
+    }
     if (!strcmp(argv[1],"encap")) {
       if (argc<3)
 	usage();
