@@ -1,3 +1,11 @@
+#!/bin/sh
+
+if [ "`id | grep uid=0`" = "" ]; then
+	echo "In order to create device inodes, you must run this script"
+	echo "as root."
+	exit 1
+fi
+echo "Creating device inodes ..."
 
 DEV=/dev
 
@@ -7,6 +15,7 @@ rm -f $DEV/isdnctrl*
 while [ $MIN -lt 16 ] ; do
 #	mknod -m 600 $DEV/isdn$MIN c $MAJ $MIN
 	mknod -m 600 $DEV/isdnctrl$MIN c $MAJ `expr $MIN + 16`
+	mknod -m 600 $DEV/ippp$MIN c $MAJ `expr $MIN + 32`
 	MIN=`expr $MIN + 1`
 done
 rm -f $DEV/isdninfo
