@@ -2,23 +2,20 @@
 #include <linux/types.h>
 #include <linux/stddef.h>
 #include <linux/timer.h>
-
-#include "isdnif.h"
 #include "teles.h"
 
 /*
     This structure array contains one entry per card. An entry looks
     like this:
 
-                { membase,irq,portbase,reserved,NULL }
+                { membase,irq,portbase,protocol,NULL }
     
-    Do NOT change the reserved-field for now!
     Cards which don't have an io port (Teles 8 bit cards for
     example) can be entered with io port 0x0
 */
 
 struct IsdnCard cards[]={
-  { (byte *)0xd0000,10,0xd80,0,NULL },  /* example */
+  { (byte *)0xd0000,15,0xd80,PROTO_1TR6,NULL },  /* example */
   { NULL,0,0,0,NULL },
   { NULL,0,0,0,NULL },
   { NULL,0,0,0,NULL },
