@@ -5,8 +5,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
-
-#include <isdn.h>
+#include <linux/isdn.h>
 
 char *progname;
 
